﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------------------------

*Select double discrimination blocks of IAT data

DATASET NAME Exp2IAT.
DATASET ACTIVATE Exp2IAT.
SELECT IF (block = "B3" | block = "B4" | block = "B6" | block = "B7").
EXECUTE.

*Compute and compare response times and accuracy between congruent and incongruent blocks 
*response time = rt.cor (time to correct response)
*accuracy = acc

AGGREGATE
  /OUTFILE= *
  /BREAK=no age german condition task 
  /m_rt.cor=MEAN(rt.cor)
  /m_acc=MEAN(acc).

SORT CASES BY no age german condition task.
CASESTOVARS
  /ID=no age german condition
  /INDEX=task
  /GROUPBY=VARIABLE.

T-TEST PAIRS=m_rt.cor.incongruen m_acc.incongruen WITH m_rt.cor.congruent m_acc.congruent (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


*----------------------------------------------------------------------------------------------------------------------------------------------
*Compute D-Scores as described by Lane, Banaji, Nosek, and Greenwald (2007, p. 92)
*-----------------------------------------------------------------------------------------------------------------------------------------------

*-----------------------------------------------------------------------------------------------------------------------------------------------
*Step 1
*Exclude trials with response times larger 10000 ms (response time = time to correct response (rt.cor))

DATASET ACTIVATE Exp2IAT.
SELECT IF (rt.cor <= 10000).
EXECUTE.

*------------------------------------------------------------------------------------------------------------------------------------------------
*Step 2
*Exclude participants for whom more than 10% of trials have response times (rt.cor) less than 300 ms

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=no
  /rt_pct300=PLT(rt.cor 300).

SELECT IF (rt_pct300 <= 10).
EXECUTE.

*--------------------------------------------------------------------------------------------------------------------------------------------
*Step 3 
*Compute inclusive SDs for rt.cor per participant for practice blocks (B3, B6) and test blocks (B4, B7)

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=no function
  /sd_rt.cor=SD(rt.cor).

*--------------------------------------------------------------------------------------------------------------------------------------------
*Step 4
*Compute Means for rt.cor per participant and each IAT block (B3, B4, B6, B7) 
*And transform data to wide format

AGGREGATE
  /OUTFILE= *
  /BREAK=no age german condition block sd_rt.cor
  /m_rt.cor=MEAN(rt.cor).

SORT CASES BY no age german condition block.
CASESTOVARS
  /ID=no age german condition
  /INDEX=block
  /GROUPBY=VARIABLE.

RENAME VARIABLES (sd_rt.cor.B3 sd_rt.cor.B4 = sd_rt.cor.prac sd_rt.cor.test).
DELETE VARIABLES sd_rt.cor.B6.
DELETE VARIABLES sd_rt.cor.B7.

*---------------------------------------------------------------------------------------------------------------------------------------------------------
*Step 5
*Compute mean differences in rt.cor between congruent and incongruent blocks seperately for practice and test.

COMPUTE m_diff.prac=m_rt.cor.B6-m_rt.cor.B3.
COMPUTE m_diff.test=m_rt.cor.B7-m_rt.cor.B4.
EXECUTE.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*Step 6
*Divide each difference score by its associated inclusive SD

COMPUTE d.prac = m_diff.prac/sd_rt.cor.prac.
COMPUTE d.test = m_diff.test/sd_rt.cor.test.
EXECUTE.

*---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*Step 7
*Compute D-Score by calculating the average of the two ratios (d.practice and d.test)

COMPUTE D.score=MEAN(d.prac,d.test).
EXECUTE.

DATASET NAME Exp2DScores.
*----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

*Compute Descriptives for D-score

DESCRIPTIVES VARIABLES=D.score
  /STATISTICS=MEAN STDDEV MIN MAX.

*Test if D-score differs significantly from zero

T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES=D.score
  /CRITERIA=CI(.95).

*----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
